const express = require('express');
const app = express();

// dossier public (pour le css, etc.)
const path = require('path');
app.use(express.static(path.join(__dirname, 'public')));

// définition du view engine
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'ejs'); // npm install --save ejs
const expressLayouts = require('express-ejs-layouts'); //npm install express-ejs-layouts
app.use(expressLayouts);
app.set('layout', '../views/layouts/layout') ; // définit le layout par défaut

// Pour le décodage des requêtes POST/PUT
app.use(express.json());
app.use(express.urlencoded({ extended: false }));


// --- ROUTES ---

// --- Paramètres de Route ---
// (exemple avec : http://127.0.0.1:3000/user/666 )

    app.get('/user/:id', (req, res) => {
        res.render('pages/show_route_params', { id_value : req.params.id } )
    });


// --- Paramètres GET ---
// (exemple avec : http://127.0.0.1:3000/?day=9&month=octobre&year=1971 )

    app.get("/", (req, res, next) => {
        let query = req.query ; // récupération des paramètres GET
        res.render('pages/show_get_params', { query })
    });


    // --- Page de formulaire ---
    app.get("/form", (req, res, next)=>{
        res.render('pages/smpl_form')
    })

    // --- Traitement des données du formulaire par méthode POST ---
    // (la même route '/form' mais différenciée par la méthode POST)
    app.post('/form', (req, res, next)=>{
        let data = req.body ;
        // NB : ne pas envoyer au render une option nommée 'body'
        // car cela interfèrerait avec express-ejs-layouts !
        res.render('pages/show_post_data' , { data })
    })



module.exports = app